@@ -1,8 +1,16 @@
-from conftest import ROOT_PATH, TEST_PATH
 import shutil
+from pathlib import Path
+import sys
+
+sys.path.insert(0, Path(__file__).parents[1])
 
 import mypythontools
 
+# Find paths and add to sys.path to be able to import local modules
+mypythontools.tests.setup_tests()
+
+from conftest import ROOT_PATH, TEST_PATH
+
 
 def test_utils():
 
